import request from "@/utils/request.js";

/**
 * 根据商家id查询商家详情
 * @param
 */
export function getSbmerchantInfo(data) {
  return request.get("sbmerchant/info", data);
}
/**
 * 扫描二维码访问商家
 * @param
 */
export function footprintScan(data) {
  return request.get("merchant/footprint/scan", data);
}
/**
 * 查询当前登录用户的历史足迹列表
 * @param
 */
export function footprintList(data) {
  return request.get("merchant/footprint/list", data);
}
/**
 * 商家提交补货申请
 * @param
 */
export function restockSubmitAPI(data) {
  return request.post("merchant/restock/submit", data);
}

/**
 * 查询当前登录商户金属资产明细
 * @param
 */
export function fetchMerchantMetalBalanceAPI(data) {
  return request.get("merchantgoldprincipal/statistics");
}

/**
 * 根据金属类型和增减类型查询流水记录
 * @param
 */
export function fetchMerchantRecordAPI(params) {
  return request.get(
    `merchantgoldprincipal/records?metalType=${params.metalType}&limit=${params.limit}&page=${params.page}&type=${params.type}`
  );
}

/**
 * 查询当前商家的补货申请列表
 * @param
 */
export function fetchMerchantRestockListAPI(params) {
  return request.get(
    `merchant/restock/list?metalType=${params.metalType}&limit=${params.limit}&page=${params.page}`
  );
}

/**
 * 获取商家销售汇总数据
 * @param
 */
export function merchantSalesSummary(data) {
  return request.get(`order/merchant/sales/summary`, data);
}
/**
 * 获取商家销售汇总数据
 * @param
 */
export function productsList(data) {
  return request.get(`products`, data);
}
/**
 * 商品上架
 * @param
 */
export function productPutOnShell(id) {
  return request.get(`product/putOnShell/${id}`);
}
/**
 * 商品下架
 * @param
 */
export function productOffShell(id) {
  return request.get(`product/offShell/${id}`);
}
/**
 * 获取商品分类
 * @param
 */
export function productCategory(data) {
  return request.get(`category/list/tree`, data, { noAuth: true });
}
/**
 * 获取运费模板
 * @param
 */
export function templatesList(data) {
  return request.get(`express/shipping/templates/list`, data);
}
/**
 * 新增商品
 * @param
 */
export function productSave(data) {
  return request.post(`product/save`, data);
}
/**
 * 修改商品
 * @param
 */
export function productUpdate(data) {
  return request.post(`product/update`, data);
}
/**
 * 获取运费模板
 * @param
 */
export function productInfo(id) {
  return request.get(`product/info/${id}`);
}
/**
 * 商品删除
 * @param
 */
export function productDelete(id) {
  return request.get(`product/delete/${id}`);
}
/**
 * 新增商品
 * @param
 */
export function batchStatus(data) {
  return request.post(`batch/status`, data);
}

/**
 * 获取商家类目
 * @param
 */
export function getMerchantCategory(data) {
  return request.get(`sbmerchant/category/list`, data);
}
